@@ -12,6 +12,8 @@ from wxc_sdk.person_settings.forwarding import *
 from wxc_sdk.person_settings.voicemail import *
 from wxc_sdk.telephony import *
 from wxc_sdk.telephony.autoattendant import *
+from wxc_sdk.telephony.callpark import *
+from wxc_sdk.telephony.callpickup import *
 from wxc_sdk.telephony.callqueue import *
 from wxc_sdk.telephony.callqueue.announcement import *
 from wxc_sdk.telephony.calls import *
@@ -20,27 +22,28 @@ from wxc_sdk.telephony.hg_and_cq import *
 from wxc_sdk.telephony.huntgroup import *
 from wxc_sdk.telephony.paging import *
 from wxc_sdk.telephony.schedules import *
-from wxc_sdk.telephony.user_base import *
 from wxc_sdk.tokens import *
 from wxc_sdk.webhook import *
 
 __all__ = ['Agent', 'AlternateNumber', 'AlternateNumberSettings', 'Announcement', 'AudioSource', 'AutoAttendant', 
-           'AutoAttendantAction', 'AutoAttendantKeyConfiguration', 'AutoAttendantMenu', 'BargeSettings', 'CallBounce', 
-           'CallForwarding', 'CallForwardingAlways', 'CallForwardingCommon', 'CallForwardingNoAnswer', 
-           'CallForwardingNumber', 'CallForwardingNumberType', 'CallForwardingPerson', 'CallHistoryRecord', 
-           'CallPolicies', 'CallQueue', 'CallRecordingSetting', 'CallState', 'CallType', 'CallerId', 
-           'CallerIdSelectedType', 'CallsFrom', 'ComfortMessageSetting', 'CustomNumberInfo', 'CustomNumberType', 
-           'CustomNumbers', 'DND', 'DialResponse', 'Dialing', 'DistinctiveRing', 'Event', 
+           'AutoAttendantAction', 'AutoAttendantKeyConfiguration', 'AutoAttendantMenu', 'AvailableRecallHuntGroup', 
+           'BargeSettings', 'BusinessContinuity', 'CallBounce', 'CallForwarding', 'CallForwardingAlways', 
+           'CallForwardingCommon', 'CallForwardingNoAnswer', 'CallForwardingNumber', 'CallForwardingNumberType', 
+           'CallForwardingPerson', 'CallHistoryRecord', 'CallPark', 'CallParkRecall', 'CallParkSettings', 
+           'CallPickup', 'CallQueue', 'CallQueueCallPolicies', 'CallRecordingSetting', 'CallState', 'CallType', 
+           'CallerId', 'CallerIdSelectedType', 'CallsFrom', 'ComfortMessageSetting', 'CustomNumberInfo', 
+           'CustomNumberType', 'CustomNumbers', 'DND', 'DialResponse', 'Dialing', 'DistinctiveRing', 'Event', 
            'ExternalCallerIdNamePolicy', 'FeatureSelector', 'ForwardCallsTo', 'ForwardToSelection', 'ForwardingRule', 
-           'ForwardingRuleDetails', 'ForwardingSetting', 'Greeting', 'HGandCQ', 'HistoryType', 'HuntGroup', 
-           'HuntGroupDetail', 'License', 'Location', 'LocationAddress', 'MenuKey', 'MohMessageSetting', 
-           'Notification', 'NotificationRepeat', 'NotificationType', 'OverflowAction', 'OverflowSetting', 'Paging', 
-           'PeopleStatus', 'Person', 'PersonForwardingSetting', 'PersonSettingsApiChild', 'PersonType', 'Personality', 
-           'PhoneNumber', 'PhoneNumberType', 'Policy', 'QueueSettings', 'Recall', 'Record', 'RecordingState', 
+           'ForwardingRuleDetails', 'ForwardingSetting', 'Greeting', 'HGCallPolicies', 'HGandCQ', 'HistoryType', 
+           'HuntGroup', 'License', 'Location', 'LocationAddress', 'LocationCallParkSettings', 'MenuKey', 
+           'MohMessageSetting', 'NoAnswer', 'Notification', 'NotificationRepeat', 'NotificationType', 
+           'OverflowAction', 'OverflowSetting', 'Paging', 'PeopleStatus', 'Person', 'PersonForwardingSetting', 
+           'PersonPlaceAgent', 'PersonSettingsApiChild', 'PersonType', 'Personality', 'PhoneNumber', 
+           'PhoneNumberType', 'Policy', 'QueueSettings', 'Recall', 'RecallHuntGroup', 'Record', 'RecordingState', 
            'RecurWeekly', 'RecurYearlyByDate', 'RecurYearlyByDay', 'Recurrence', 'RedirectReason', 'Redirection', 
            'RingPattern', 'Schedule', 'ScheduleDay', 'ScheduleMonth', 'ScheduleType', 'ScheduleWeek', 'SipAddress', 
            'SipType', 'SiteType', 'StorageType', 'TelephonyCall', 'TelephonyEvent', 'TelephonyEventData', 
-           'TelephonyParty', 'Tokens', 'UnansweredCalls', 'UserBase', 'UserType', 'VoiceMailFax', 
+           'TelephonyParty', 'Tokens', 'UnansweredCalls', 'UserBase', 'UserNumber', 'UserType', 'VoiceMailFax', 
            'VoicemailCopyOfMessage', 'VoicemailEnabled', 'VoicemailEnabledWithGreeting', 'VoicemailFax', 
            'VoicemailMessageStorage', 'VoicemailNotifications', 'VoicemailSettings', 'VoicemailTransferToNumber', 
            'WaitMessageSetting', 'WaitMode', 'WebHook', 'WebHookCreate', 'WebHookEvent', 'WebHookResource', 
